summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:07:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:07:26 -0600
commit19e7a1afa3cd439f94b6892839c821ea82eece5c (patch)
tree13357a85c665b31550cd08791fbf4574dc5f4f00
parent86651d6d989faf513952a3ca848ab6d374b64e6e (diff)
downloadkrusader-19e7a1afa3cd439f94b6892839c821ea82eece5c.tar.gz
krusader-19e7a1afa3cd439f94b6892839c821ea82eece5c.zip
Rename KIcon to enhance compatibility with KDE4
-rw-r--r--krusader/ActionMan/actionproperty.cpp2
-rw-r--r--krusader/ActionMan/actionpropertybase.cpp2
-rw-r--r--krusader/ActionMan/actionpropertybase.ui2
-rw-r--r--krusader/ActionMan/addplaceholderpopup.cpp8
-rw-r--r--krusader/ActionMan/useractionlistview.cpp2
-rw-r--r--krusader/ActionMan/useractionpage.cpp2
-rw-r--r--krusader/BookMan/kraddbookmarkdlg.cpp4
-rw-r--r--krusader/BookMan/krbookmark.cpp6
-rw-r--r--krusader/BookMan/krbookmarkbutton.cpp2
-rw-r--r--krusader/BookMan/krbookmarkhandler.cpp14
-rw-r--r--krusader/Dialogs/checksumdlg.cpp8
-rw-r--r--krusader/Dialogs/krprogress.cpp4
-rw-r--r--krusader/Dialogs/krspwidgets.cpp2
-rw-r--r--krusader/Dialogs/kurllistrequester.cpp6
-rw-r--r--krusader/Dialogs/newftpgui.cpp2
-rw-r--r--krusader/Dialogs/packguibase.cpp2
-rw-r--r--krusader/DiskUsage/diskusagegui.cpp12
-rw-r--r--krusader/DiskUsage/radialMap/widgetEvents.cpp4
-rw-r--r--krusader/Filter/advancedfilter.cpp2
-rw-r--r--krusader/GUI/dirhistorybutton.cpp4
-rw-r--r--krusader/GUI/mediabutton.cpp4
-rw-r--r--krusader/GUI/profilemanager.cpp4
-rw-r--r--krusader/GUI/syncbrowsebutton.cpp6
-rw-r--r--krusader/KViewer/kimagefilepreview.cpp4
-rw-r--r--krusader/KViewer/krviewer.cpp6
-rw-r--r--krusader/Konfigurator/kggeneral.cpp4
-rw-r--r--krusader/Konfigurator/kgprotocols.cpp12
-rw-r--r--krusader/Konfigurator/konfigurator.cpp18
-rw-r--r--krusader/Konfigurator/krresulttabledialog.cpp2
-rw-r--r--krusader/Panel/krbriefview.cpp62
-rw-r--r--krusader/Panel/krbriefview.h8
-rw-r--r--krusader/Panel/krbriefviewitem.cpp4
-rw-r--r--krusader/Panel/krbriefviewitem.h6
-rw-r--r--krusader/Panel/krpopupmenu.cpp10
-rw-r--r--krusader/Panel/listpanel.cpp10
-rw-r--r--krusader/Panel/panelpopup.cpp16
-rw-r--r--krusader/kicons.cpp4
-rw-r--r--krusader/kicons.h4
-rw-r--r--krusader/krusader.cpp2
-rw-r--r--krusader/krusader.h4
40 files changed, 140 insertions, 140 deletions
diff --git a/krusader/ActionMan/actionproperty.cpp b/krusader/ActionMan/actionproperty.cpp
index 86fcc53..bd9561e 100644
--- a/krusader/ActionMan/actionproperty.cpp
+++ b/krusader/ActionMan/actionproperty.cpp
@@ -33,7 +33,7 @@
#include <ktextedit.h>
#include <kiconloader.h>
-#define ICON(N) TDEGlobal::iconLoader()->loadIcon(N, KIcon::Small)
+#define ICON(N) TDEGlobal::iconLoader()->loadIcon(N, TDEIcon::Small)
ActionProperty::ActionProperty( TQWidget *parent, const char *name, KrAction *action )
: ActionPropertyBase( parent, name ), _modified(false)
diff --git a/krusader/ActionMan/actionpropertybase.cpp b/krusader/ActionMan/actionpropertybase.cpp
index 6c0a839..8772048 100644
--- a/krusader/ActionMan/actionpropertybase.cpp
+++ b/krusader/ActionMan/actionpropertybase.cpp
@@ -101,7 +101,7 @@ ActionPropertyBase::ActionPropertyBase( TQWidget* parent, const char* name, WFla
layout2->addWidget( cbCategory );
layout3->addLayout( layout2 );
- ButtonIcon = new KIconButton( tab, "ButtonIcon" );
+ ButtonIcon = new TDEIconButton( tab, "ButtonIcon" );
ButtonIcon->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, ButtonIcon->sizePolicy().hasHeightForWidth() ) );
ButtonIcon->setMinimumSize( TQSize( 50, 50 ) );
ButtonIcon->setMaximumSize( TQSize( 50, 50 ) );
diff --git a/krusader/ActionMan/actionpropertybase.ui b/krusader/ActionMan/actionpropertybase.ui
index 12968f4..13980a6 100644
--- a/krusader/ActionMan/actionpropertybase.ui
+++ b/krusader/ActionMan/actionpropertybase.ui
@@ -177,7 +177,7 @@
</widget>
</vbox>
</widget>
- <widget class="KIconButton">
+ <widget class="TDEIconButton">
<property name="name">
<cstring>ButtonIcon</cstring>
</property>
diff --git a/krusader/ActionMan/addplaceholderpopup.cpp b/krusader/ActionMan/addplaceholderpopup.cpp
index 1806702..4ea8e50 100644
--- a/krusader/ActionMan/addplaceholderpopup.cpp
+++ b/krusader/ActionMan/addplaceholderpopup.cpp
@@ -345,8 +345,8 @@ ParameterFile::ParameterFile( const exp_parameter& parameter, TQWidget* parent )
hbox->setSpacing( 6 );
_lineEdit = new KLineEdit( hbox );
_button = new TQToolButton( hbox);
- KIconLoader *iconLoader = new KIconLoader();
- _button->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+ TDEIconLoader *iconLoader = new TDEIconLoader();
+ _button->setPixmap( iconLoader->loadIcon( "fileopen", TDEIcon::Toolbar, 16 ) );
connect( _button, TQT_SIGNAL(clicked()), this, TQT_SLOT(addFile()) );
}
@@ -438,8 +438,8 @@ ParameterGoto::ParameterGoto( const exp_parameter& parameter, TQWidget* parent )
_lineEdit = new KLineEdit( hbox );
_lineEdit->setCompletionObject( new KURLCompletion( KURLCompletion::DirCompletion ) );
_dirButton = new TQToolButton( hbox );
- KIconLoader *iconLoader = new KIconLoader();
- _dirButton->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+ TDEIconLoader *iconLoader = new TDEIconLoader();
+ _dirButton->setPixmap( iconLoader->loadIcon( "fileopen", TDEIcon::Toolbar, 16 ) );
connect( _dirButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(setDir()) );
_placeholderButton = new TQToolButton( hbox);
_placeholderButton->setText( i18n("add") );
diff --git a/krusader/ActionMan/useractionlistview.cpp b/krusader/ActionMan/useractionlistview.cpp
index 6eb7b11..c0d29d6 100644
--- a/krusader/ActionMan/useractionlistview.cpp
+++ b/krusader/ActionMan/useractionlistview.cpp
@@ -214,7 +214,7 @@ void UserActionListViewItem::update() {
return;
if ( ! _action->icon().isEmpty() )
- setPixmap( COL_TITLE, TDEGlobal::iconLoader()->loadIcon( _action->icon(), KIcon::Small ) );
+ setPixmap( COL_TITLE, TDEGlobal::iconLoader()->loadIcon( _action->icon(), TDEIcon::Small ) );
setText( COL_TITLE, _action->text() );
setText( COL_NAME, _action->name() );
}
diff --git a/krusader/ActionMan/useractionpage.cpp b/krusader/ActionMan/useractionpage.cpp
index d7736a8..732ae8e 100644
--- a/krusader/ActionMan/useractionpage.cpp
+++ b/krusader/ActionMan/useractionpage.cpp
@@ -29,7 +29,7 @@
#include "../UserAction/kraction.h"
#include "../krusader.h"
-#define ICON(N) TDEGlobal::iconLoader()->loadIcon(N, KIcon::Toolbar)
+#define ICON(N) TDEGlobal::iconLoader()->loadIcon(N, TDEIcon::Toolbar)
//This is the filter in the KFileDialog of Import/Export:
static const char* FILE_FILTER = I18N_NOOP("*.xml|xml-files\n*|all files");
diff --git a/krusader/BookMan/kraddbookmarkdlg.cpp b/krusader/BookMan/kraddbookmarkdlg.cpp
index 84d4d17..8ac404a 100644
--- a/krusader/BookMan/kraddbookmarkdlg.cpp
+++ b/krusader/BookMan/kraddbookmarkdlg.cpp
@@ -44,7 +44,7 @@ KrAddBookmarkDlg::KrAddBookmarkDlg(TQWidget *parent, KURL url):
_folder->setReadOnly(true);
_createInBtn = new TQToolButton(page);
- _createInBtn->setPixmap(krLoader->loadIcon("down", KIcon::Small));
+ _createInBtn->setPixmap(krLoader->loadIcon("down", TDEIcon::Small));
_createInBtn->setToggleButton(true);
connect(_createInBtn, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(toggleCreateIn(bool )));
layout->addWidget(_createInBtn, 2, 2);
@@ -55,7 +55,7 @@ KrAddBookmarkDlg::KrAddBookmarkDlg(TQWidget *parent, KURL url):
}
void KrAddBookmarkDlg::toggleCreateIn(bool show) {
- _createInBtn->setPixmap(krLoader->loadIcon(show ? "up" :"down", KIcon::Small));
+ _createInBtn->setPixmap(krLoader->loadIcon(show ? "up" :"down", TDEIcon::Small));
showButton(KDialogBase::User1, show);
setDetails(show);
}
diff --git a/krusader/BookMan/krbookmark.cpp b/krusader/BookMan/krbookmark.cpp
index fc18489..ba83b57 100644
--- a/krusader/BookMan/krbookmark.cpp
+++ b/krusader/BookMan/krbookmark.cpp
@@ -54,7 +54,7 @@ KrBookmark* KrBookmark::devices(TDEActionCollection *collection) {
#else
bm = new KrBookmark(i18n(NAME_DEVICES), "devices:/", collection);
#endif
- bm->setIconSet(krLoader->loadIcon("blockdevice", KIcon::Small));
+ bm->setIconSet(krLoader->loadIcon("blockdevice", TDEIcon::Small));
}
return bm;
}
@@ -63,7 +63,7 @@ KrBookmark* KrBookmark::virt(TDEActionCollection *collection) {
KrBookmark *bm = getExistingBookmark(i18n(NAME_VIRTUAL), collection);
if (!bm) {
bm = new KrBookmark(i18n(NAME_VIRTUAL), "virt:/", collection);
- bm->setIconSet(krLoader->loadIcon("pipe", KIcon::Small));
+ bm->setIconSet(krLoader->loadIcon("pipe", TDEIcon::Small));
}
return bm;
}
@@ -72,7 +72,7 @@ KrBookmark* KrBookmark::lan(TDEActionCollection *collection) {
KrBookmark *bm = getExistingBookmark(i18n(NAME_LAN), collection);
if (!bm) {
bm = new KrBookmark(i18n(NAME_LAN), "lan:/", collection);
- bm->setIconSet(krLoader->loadIcon("network", KIcon::Small));
+ bm->setIconSet(krLoader->loadIcon("network", TDEIcon::Small));
}
return bm;
}
diff --git a/krusader/BookMan/krbookmarkbutton.cpp b/krusader/BookMan/krbookmarkbutton.cpp
index e7c0972..ffda2bf 100644
--- a/krusader/BookMan/krbookmarkbutton.cpp
+++ b/krusader/BookMan/krbookmarkbutton.cpp
@@ -9,7 +9,7 @@
#include <kdebug.h>
KrBookmarkButton::KrBookmarkButton(TQWidget *parent): TQToolButton(parent) {
- TQPixmap icon = krLoader->loadIcon("bookmark", KIcon::Toolbar, 16);
+ TQPixmap icon = krLoader->loadIcon("bookmark", TDEIcon::Toolbar, 16);
setFixedSize(icon.width() + 4, icon.height() + 4);
setPixmap(icon);
setTextLabel(i18n("BookMan II"), true);
diff --git a/krusader/BookMan/krbookmarkhandler.cpp b/krusader/BookMan/krbookmarkhandler.cpp
index b62cd15..d91b6f4 100644
--- a/krusader/BookMan/krbookmarkhandler.cpp
+++ b/krusader/BookMan/krbookmarkhandler.cpp
@@ -287,7 +287,7 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, TDEPopupMenu *menu) {
for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
if (!bm->isFolder()) continue;
TDEPopupMenu *newMenu = new TDEPopupMenu(menu);
- int id = menu->insertItem(TQIconSet(krLoader->loadIcon(bm->icon(), KIcon::Small)),
+ int id = menu->insertItem(TQIconSet(krLoader->loadIcon(bm->icon(), TDEIcon::Small)),
bm->text(), newMenu, -1 /* dummy id */, -1 /* end of list */);
if( !_bookmarkIDTable.find( menu ) )
@@ -328,7 +328,7 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, TDEPopupMenu *menu) {
// add the popular links submenu
TDEPopupMenu *newMenu = new TDEPopupMenu(menu);
- itemIndex = menu->insertItem(TQIconSet(krLoader->loadIcon("bookmark_folder", KIcon::Small)),
+ itemIndex = menu->insertItem(TQIconSet(krLoader->loadIcon("bookmark_folder", TDEIcon::Small)),
i18n("Popular URLs"), newMenu, -1 /* dummy id */, -1 /* end of list */);
_specialBookmarkIDs.append( itemIndex );
// add the top 15 urls
@@ -395,10 +395,10 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, TDEPopupMenu *menu) {
if( !hasJumpback )
menu->insertSeparator();
- itemIndex = menu->insertItem(krLoader->loadIcon("bookmark_add", KIcon::Small),
+ itemIndex = menu->insertItem(krLoader->loadIcon("bookmark_add", TDEIcon::Small),
i18n("Bookmark Current"), BookmarkCurrent);
_specialBookmarkIDs.append( itemIndex );
- itemIndex = menu->insertItem(krLoader->loadIcon("bookmark", KIcon::Small),
+ itemIndex = menu->insertItem(krLoader->loadIcon("bookmark", TDEIcon::Small),
i18n("Manage Bookmarks"), ManageBookmarks);
_specialBookmarkIDs.append( itemIndex );
@@ -535,10 +535,10 @@ void KrBookmarkHandler::rightClickOnSpecialBookmark() {
void KrBookmarkHandler::rightClicked( TQPopupMenu *menu, int /*id*/, KrBookmark * bm ) {
TQPopupMenu popup( _mainBookmarkPopup );
- popup.insertItem( krLoader->loadIcon( "fileopen", KIcon::Panel ), i18n( "Open" ), OPEN_ID );
- popup.insertItem( krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in a new tab" ), OPEN_NEW_TAB_ID );
+ popup.insertItem( krLoader->loadIcon( "fileopen", TDEIcon::Panel ), i18n( "Open" ), OPEN_ID );
+ popup.insertItem( krLoader->loadIcon( "tab_new", TDEIcon::Panel ), i18n( "Open in a new tab" ), OPEN_NEW_TAB_ID );
popup.insertSeparator();
- popup.insertItem( krLoader->loadIcon( "editdelete", KIcon::Panel ), i18n( "Delete" ), DELETE_ID );
+ popup.insertItem( krLoader->loadIcon( "editdelete", TDEIcon::Panel ), i18n( "Delete" ), DELETE_ID );
connect( menu, TQT_SIGNAL( highlighted( int ) ), &popup, TQT_SLOT( close() ) );
connect( menu, TQT_SIGNAL( activated( int ) ), &popup, TQT_SLOT( close() ) );
diff --git a/krusader/Dialogs/checksumdlg.cpp b/krusader/Dialogs/checksumdlg.cpp
index 2bbd022..3087741 100644
--- a/krusader/Dialogs/checksumdlg.cpp
+++ b/krusader/Dialogs/checksumdlg.cpp
@@ -230,7 +230,7 @@ CreateChecksumDlg::CreateChecksumDlg(const TQStringList& files, bool containFold
// title (icon+text)
TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
TQLabel *p = new TQLabel(plainPage());
- p->setPixmap(krLoader->loadIcon("binary", KIcon::Desktop, 32));
+ p->setPixmap(krLoader->loadIcon("binary", TDEIcon::Desktop, 32));
hlayout->addWidget(p);
TQLabel *l1 = new TQLabel(i18n("About to calculate checksum for the following files") +
(containFolders ? i18n(" and folders:") : ":"), plainPage());
@@ -331,7 +331,7 @@ MatchChecksumDlg::MatchChecksumDlg(const TQStringList& files, bool containFolder
// title (icon+text)
TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
TQLabel *p = new TQLabel(plainPage());
- p->setPixmap(krLoader->loadIcon("binary", KIcon::Desktop, 32));
+ p->setPixmap(krLoader->loadIcon("binary", TDEIcon::Desktop, 32));
hlayout->addWidget(p);
TQLabel *l1 = new TQLabel(i18n("About to verify checksum for the following files") +
(containFolders ? i18n(" and folders:") : ":"), plainPage());
@@ -437,7 +437,7 @@ VerifyResultDlg::VerifyResultDlg(const TQStringList& failed):
// create the icon and title
TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
TQLabel p(plainPage());
- p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", KIcon::Desktop, 32));
+ p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", TDEIcon::Desktop, 32));
hlayout->addWidget(&p);
TQLabel *l1 = new TQLabel((errors ? i18n("Errors were detected while verifying the checksums") :
@@ -475,7 +475,7 @@ ChecksumResultsDlg::ChecksumResultsDlg(const TQStringList& stdOut, const TQStrin
// create the icon and title
TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
TQLabel p(plainPage());
- p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", KIcon::Desktop, 32));
+ p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", TDEIcon::Desktop, 32));
hlayout->addWidget(&p);
TQLabel *l1 = new TQLabel((errors ? i18n("Errors were detected while creating the checksums") :
diff --git a/krusader/Dialogs/krprogress.cpp b/krusader/Dialogs/krprogress.cpp
index b037d88..2e7893c 100644
--- a/krusader/Dialogs/krprogress.cpp
+++ b/krusader/Dialogs/krprogress.cpp
@@ -44,8 +44,8 @@ KrProgress::KrProgress( TDEIO::Job* job )
#ifdef TQ_WS_X11 //FIXME(E): Remove once all the KWin::foo calls have been ported to TQWS
// Set a useful icon for this window!
KWin::setIcons( winId(),
- TDEGlobal::iconLoader()->loadIcon( "filesave", KIcon::NoGroup, 32 ),
- TDEGlobal::iconLoader()->loadIcon( "filesave", KIcon::NoGroup, 16 ) );
+ TDEGlobal::iconLoader()->loadIcon( "filesave", TDEIcon::NoGroup, 32 ),
+ TDEGlobal::iconLoader()->loadIcon( "filesave", TDEIcon::NoGroup, 16 ) );
#endif
TQVBoxLayout *topLayout = new TQVBoxLayout( this, KDialog::marginHint(),
diff --git a/krusader/Dialogs/krspwidgets.cpp b/krusader/Dialogs/krspwidgets.cpp
index 830954a..5641ffc 100644
--- a/krusader/Dialogs/krspwidgets.cpp
+++ b/krusader/Dialogs/krspwidgets.cpp
@@ -147,7 +147,7 @@ void newFTPSub::reject() {
/////////////////////////// KRMaskChoiceSub ///////////////////////////////
KRMaskChoiceSub::KRMaskChoiceSub() : KRMaskChoice(0,0,true) {
- PixmapLabel1->setPixmap(krLoader->loadIcon("kr_select", KIcon::Desktop, 32));
+ PixmapLabel1->setPixmap(krLoader->loadIcon("kr_select", TDEIcon::Desktop, 32));
label->setText(i18n("Enter a selection:"));
// the predefined selections list
krConfig->setGroup("Private");
diff --git a/krusader/Dialogs/kurllistrequester.cpp b/krusader/Dialogs/kurllistrequester.cpp
index b23919e..aa74ece 100644
--- a/krusader/Dialogs/kurllistrequester.cpp
+++ b/krusader/Dialogs/kurllistrequester.cpp
@@ -43,9 +43,9 @@
KURLListRequester::KURLListRequester( TQWidget *parent, const char * name ) : TQWidget( parent, name )
{
- KIconLoader *iconLoader = new KIconLoader();
- TQPixmap imageAdd = iconLoader->loadIcon( "1downarrow", KIcon::Panel, 16 );
- TQPixmap imageFolder = iconLoader->loadIcon( "folder", KIcon::Panel, 16 );
+ TDEIconLoader *iconLoader = new TDEIconLoader();
+ TQPixmap imageAdd = iconLoader->loadIcon( "1downarrow", TDEIcon::Panel, 16 );
+ TQPixmap imageFolder = iconLoader->loadIcon( "folder", TDEIcon::Panel, 16 );
// Creating the widget
diff --git a/krusader/Dialogs/newftpgui.cpp b/krusader/Dialogs/newftpgui.cpp
index 7dadc7f..79ef77c 100644
--- a/krusader/Dialogs/newftpgui.cpp
+++ b/krusader/Dialogs/newftpgui.cpp
@@ -56,7 +56,7 @@ newFTPGUI::newFTPGUI( TQWidget* parent, const char* name, bool modal, WFlags fl
hbox_image->setSpacing( 6 );
PixmapLabel1 = new TQLabel( hbox_image, "PixmapLabel1" );
- PixmapLabel1->setPixmap( krLoader->loadIcon("network", KIcon::Desktop, 32) );
+ PixmapLabel1->setPixmap( krLoader->loadIcon("network", TDEIcon::Desktop, 32) );
PixmapLabel1->setSizePolicy( SIZE_MINIMUM );
TextLabel3 = new TQLabel( i18n( "About to connect to..." ), hbox_image, "TextLabel3" );
diff --git a/krusader/Dialogs/packguibase.cpp b/krusader/Dialogs/packguibase.cpp
index f3d7430..3ed263f 100644
--- a/krusader/Dialogs/packguibase.cpp
+++ b/krusader/Dialogs/packguibase.cpp
@@ -113,7 +113,7 @@ PackGUIBase::PackGUIBase( TQWidget* parent, const char* name, bool modal, WFlag
hbox_3->setMargin( 0 );
PixmapLabel1 = new TQLabel( this, "PixmapLabel1" );
- PixmapLabel1->setPixmap( krLoader->loadIcon("package", KIcon::Desktop, 32) );
+ PixmapLabel1->setPixmap( krLoader->loadIcon("package", TDEIcon::Desktop, 32) );
PixmapLabel1->setScaledContents( TRUE );
PixmapLabel1->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0 ) );
hbox_3->addWidget( PixmapLabel1 );
diff --git a/krusader/DiskUsage/diskusagegui.cpp b/krusader/DiskUsage/diskusagegui.cpp
index accd9f4..d8ac5d5 100644
--- a/krusader/DiskUsage/diskusagegui.cpp
+++ b/krusader/DiskUsage/diskusagegui.cpp
@@ -56,32 +56,32 @@ DiskUsageGUI::DiskUsageGUI( KURL openDir, TQWidget* parent, const char *name )
duTools->setSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed );
btnNewSearch = new TQToolButton( duTools, "btnNewSearch" );
- btnNewSearch->setIconSet( TQIconSet(krLoader->loadIcon("fileopen",KIcon::Desktop)) );
+ btnNewSearch->setIconSet( TQIconSet(krLoader->loadIcon("fileopen",TDEIcon::Desktop)) );
TQToolTip::add( btnNewSearch, i18n( "Start new disk usage search" ) );
btnRefresh = new TQToolButton( duTools, "btnRefresh" );
- btnRefresh->setIconSet( TQIconSet(krLoader->loadIcon("reload",KIcon::Desktop)) );
+ btnRefresh->setIconSet( TQIconSet(krLoader->loadIcon("reload",TDEIcon::Desktop)) );
TQToolTip::add( btnRefresh, i18n( "Refresh" ) );
btnDirUp = new TQToolButton( duTools, "btnDirUp" );
- btnDirUp->setIconSet( TQIconSet(krLoader->loadIcon("up",KIcon::Desktop)) );
+ btnDirUp->setIconSet( TQIconSet(krLoader->loadIcon("up",TDEIcon::Desktop)) );
TQToolTip::add( btnDirUp, i18n( "Parent directory" ) );
TQWidget * separatorWidget = new TQWidget( duTools, "separatorWidget" );
separatorWidget->setMinimumWidth( 10 );
btnLines = new TQToolButton( duTools, "btnLines" );
- btnLines->setIconSet( TQIconSet(krLoader->loadIcon("leftjust",KIcon::Desktop)) );
+ btnLines->setIconSet( TQIconSet(krLoader->loadIcon("leftjust",TDEIcon::Desktop)) );
btnLines->setToggleButton( true );
TQToolTip::add( btnLines, i18n( "Line view" ) );
btnDetailed = new TQToolButton( duTools, "btnDetailed" );
- btnDetailed->setIconSet( TQIconSet(krLoader->loadIcon("view_detailed",KIcon::Desktop)) );
+ btnDetailed->setIconSet( TQIconSet(krLoader->loadIcon("view_detailed",TDEIcon::Desktop)) );
btnDetailed->setToggleButton( true );
TQToolTip::add( btnDetailed, i18n( "Detailed view" ) );
btnFilelight = new TQToolButton( duTools, "btnFilelight" );
- btnFilelight->setIconSet( TQIconSet(krLoader->loadIcon("kr_diskusage",KIcon::Desktop)) );
+ btnFilelight->setIconSet( TQIconSet(krLoader->loadIcon("kr_diskusage",TDEIcon::Desktop)) );
btnFilelight->setToggleButton( true );
TQToolTip::add( btnFilelight, i18n( "Filelight view" ) );
diff --git a/krusader/DiskUsage/radialMap/widgetEvents.cpp b/krusader/DiskUsage/radialMap/widgetEvents.cpp
index e044a99..fd53781 100644
--- a/krusader/DiskUsage/radialMap/widgetEvents.cpp
+++ b/krusader/DiskUsage/radialMap/widgetEvents.cpp
@@ -216,12 +216,12 @@ RadialMap::Widget::mousePressEvent( TQMouseEvent *e )
if( !isDir || e->button() == Qt::MidButton )
{
- KIconEffect::visualActivate( this, rect );
+ TDEIconEffect::visualActivate( this, rect );
new KRun( url, this, true ); //FIXME see above
}
else if( m_focus->file() != m_tree ) //is left mouse button
{
- KIconEffect::visualActivate( this, rect );
+ TDEIconEffect::visualActivate( this, rect );
emit activated( url ); //activate first, this will cause UI to prepare itself
if( m_focus )
createFromCache( (Directory *)m_focus->file() );
diff --git a/krusader/Filter/advancedfilter.cpp b/krusader/Filter/advancedfilter.cpp
index 80672be..e22a6aa 100644
--- a/krusader/Filter/advancedfilter.cpp
+++ b/krusader/Filter/advancedfilter.cpp
@@ -107,7 +107,7 @@ AdvancedFilter::AdvancedFilter( FilterTabs *tabs, TQWidget *parent, const char *
// Options for date
- TQPixmap iconDate = krLoader->loadIcon( "date", KIcon::Toolbar, 16 );
+ TQPixmap iconDate = krLoader->loadIcon( "date", TDEIcon::Toolbar, 16 );
TQButtonGroup *dateGroup = new TQButtonGroup( this, "dateGroup" );
dateGroup->setTitle( i18n( "Date" ) );
diff --git a/krusader/GUI/dirhistorybutton.cpp b/krusader/GUI/dirhistorybutton.cpp
index 68c42dd..6f2b0f1 100644
--- a/krusader/GUI/dirhistorybutton.cpp
+++ b/krusader/GUI/dirhistorybutton.cpp
@@ -27,8 +27,8 @@
#include <kdebug.h>
DirHistoryButton::DirHistoryButton( DirHistoryQueue* hQ, TQWidget *parent, const char *name ) : TQToolButton( parent, name ) {
- KIconLoader * iconLoader = new KIconLoader();
- TQPixmap icon = iconLoader->loadIcon( "history", KIcon::Toolbar, 16 );
+ TDEIconLoader * iconLoader = new TDEIconLoader();
+ TQPixmap icon = iconLoader->loadIcon( "history", TDEIcon::Toolbar, 16 );
setFixedSize( icon.width() + 4, icon.height() + 4 );
setPixmap( icon );
diff --git a/krusader/GUI/mediabutton.cpp b/krusader/GUI/mediabutton.cpp
index 152fd61..30400ee 100644
--- a/krusader/GUI/mediabutton.cpp
+++ b/krusader/GUI/mediabutton.cpp
@@ -73,8 +73,8 @@
MediaButton::MediaButton( TQWidget *parent, const char *name ) : TQToolButton( parent, name ),
popupMenu( 0 ), rightMenu( 0 ), hasMedia( false ), waitingForMount( -1 ), mountCheckerTimer()
{
- KIconLoader * iconLoader = new KIconLoader();
- TQPixmap icon = iconLoader->loadIcon( "blockdevice", KIcon::Toolbar, 16 );
+ TDEIconLoader * iconLoader = new TDEIconLoader();
+ TQPixmap icon = iconLoader->loadIcon( "blockdevice", TDEIcon::Toolbar, 16 );
setFixedSize( icon.width() + 4, icon.height() + 4 );
setPixmap( icon );
diff --git a/krusader/GUI/profilemanager.cpp b/krusader/GUI/profilemanager.cpp
index 9ad5b41..e25afab 100644
--- a/krusader/GUI/profilemanager.cpp
+++ b/krusader/GUI/profilemanager.cpp
@@ -42,8 +42,8 @@ ProfileManager::ProfileManager( TQString profileType, TQWidget * parent, const c
: TQPushButton( parent, name )
{
setText( "" );
- KIconLoader *iconLoader = new KIconLoader();
- setPixmap( iconLoader->loadIcon( "kr_profile", KIcon::Toolbar, 16 ) );
+ TDEIconLoader *iconLoader = new TDEIconLoader();
+ setPixmap( iconLoader->loadIcon( "kr_profile", TDEIcon::Toolbar, 16 ) );
TQToolTip::add( this, i18n( "Profiles" ) );
this->profileType = profileType;
diff --git a/krusader/GUI/syncbrowsebutton.cpp b/krusader/GUI/syncbrowsebutton.cpp
index bcd2b91..99a3397 100644
--- a/krusader/GUI/syncbrowsebutton.cpp
+++ b/krusader/GUI/syncbrowsebutton.cpp
@@ -34,9 +34,9 @@ The current version only manages sync-browse and got no mode-switch options.
SyncBrowseButton::SyncBrowseButton(TQWidget *parent, const char *name) : TQToolButton(parent,name)
{
- KIconLoader *iconLoader = new KIconLoader();
- _icon_on = iconLoader->loadIcon( "kr_syncbrowse_on", KIcon::Toolbar, 16 );
- _icon_off = iconLoader->loadIcon( "kr_syncbrowse_off", KIcon::Toolbar, 16 );
+ TDEIconLoader *iconLoader = new TDEIconLoader();
+ _icon_on = iconLoader->loadIcon( "kr_syncbrowse_on", TDEIcon::Toolbar, 16 );
+ _icon_off = iconLoader->loadIcon( "kr_syncbrowse_off", TDEIcon::Toolbar, 16 );
setFixedSize( _icon_off.width() + 4, _icon_off.height() + 4 );
setPixmap( _icon_off );
diff --git a/krusader/KViewer/kimagefilepreview.cpp b/krusader/KViewer/kimagefilepreview.cpp
index 782e640..4aa7383 100644
--- a/krusader/KViewer/kimagefilepreview.cpp
+++ b/krusader/KViewer/kimagefilepreview.cpp
@@ -110,8 +110,8 @@ void KrusaderImageFilePreview::slotFailed( const KFileItem* item ) {
if ( item->isDir() )
imageLabel->clear();
else if ( item->url() == currentURL ) // should always be the case
- imageLabel->setPixmap( SmallIcon( "file_broken", KIcon::SizeLarge,
- KIcon::DisabledState ) );
+ imageLabel->setPixmap( SmallIcon( "file_broken", TDEIcon::SizeLarge,
+ TDEIcon::DisabledState ) );
}
void KrusaderImageFilePreview::slotResult( TDEIO::Job *job ) {
diff --git a/krusader/KViewer/krviewer.cpp b/krusader/KViewer/krviewer.cpp
index be444ee..77418a8 100644
--- a/krusader/KViewer/krviewer.cpp
+++ b/krusader/KViewer/krviewer.cpp
@@ -301,7 +301,7 @@ void KrViewer::addTab(PanelViewerBase* pvb, TQString msg, TQString iconName ,KPa
KURL url = pvb->url();
setCaption( msg+": " + url.prettyURL() );
- TQIconSet icon = TQIconSet(krLoader->loadIcon(iconName,KIcon::Small));
+ TQIconSet icon = TQIconSet(krLoader->loadIcon(iconName,TDEIcon::Small));
manager.addPart( part, this );
manager.setActivePart( part );
@@ -453,7 +453,7 @@ void KrViewer::checkModified(){
TQString label = tabBar.tabLabel(pvb);
if( !label.startsWith("*" + pvb->part()->url().fileName() ) ){
label.prepend("*");
- TQIconSet icon = TQIconSet(krLoader->loadIcon(MODIFIED_ICON,KIcon::Small));
+ TQIconSet icon = TQIconSet(krLoader->loadIcon(MODIFIED_ICON,TDEIcon::Small));
tabBar.changeTab(pvb,icon,label);
}
@@ -463,7 +463,7 @@ void KrViewer::checkModified(){
TQString label = tabBar.tabLabel(pvb);
if( label.startsWith("*" + pvb->part()->url().fileName() ) ){
label = label.mid( 1 );
- TQIconSet icon = TQIconSet(krLoader->loadIcon(EDIT_ICON,KIcon::Small));
+ TQIconSet icon = TQIconSet(krLoader->loadIcon(EDIT_ICON,TDEIcon::Small));
tabBar.changeTab(pvb,icon,label);
}
diff --git a/krusader/Konfigurator/kggeneral.cpp b/krusader/Konfigurator/kggeneral.cpp
index 0c40482..f11c59b 100644
--- a/krusader/Konfigurator/kggeneral.cpp
+++ b/krusader/Konfigurator/kggeneral.cpp
@@ -117,13 +117,13 @@ TQFrame *line2 = createLine( generalGrp, "line2" );
int size = TQFontMetrics( atomLabel->font() ).height();
TQToolButton *addButton = new TQToolButton( hbox3, "addBtnList" );
- TQPixmap icon = krLoader->loadIcon("add",KIcon::Desktop, size );
+ TQPixmap icon = krLoader->loadIcon("add",TDEIcon::Desktop, size );
addButton->setFixedSize( icon.width() + 4, icon.height() + 4 );
addButton->setPixmap( icon );
connect( addButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddExtension() ) );
TQToolButton *removeButton = new TQToolButton( hbox3, "removeBtnList" );
- icon = krLoader->loadIcon("remove",KIcon::Desktop, size );
+ icon = krLoader->loadIcon("remove",TDEIcon::Desktop, size );
removeButton->setFixedSize( icon.width() + 4, icon.height() + 4 );
removeButton->setPixmap( icon );
connect( removeButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRemoveExtension() ) );
diff --git a/krusader/Konfigurator/kgprotocols.cpp b/krusader/Konfigurator/kgprotocols.cpp
index 08b613a..a6b512c 100644
--- a/krusader/Konfigurator/kgprotocols.cpp
+++ b/krusader/Konfigurator/kgprotocols.cpp
@@ -81,10 +81,10 @@ KgProtocols::KgProtocols( bool first, TQWidget* parent, const char* name ) :
addSpacer( vbox1 );
btnAddProtocol = new TQPushButton( vbox1, "btnAddProtocolButton" );
- btnAddProtocol->setPixmap( krLoader->loadIcon( "1leftarrow", KIcon::Small ) );
+ btnAddProtocol->setPixmap( krLoader->loadIcon( "1leftarrow", TDEIcon::Small ) );
TQWhatsThis::add( btnAddProtocol, i18n( "Add protocol to the link list." ) );
btnRemoveProtocol = new TQPushButton( vbox1, "btnRemoveProtocolButton" );
- btnRemoveProtocol->setPixmap( krLoader->loadIcon( "1rightarrow", KIcon::Small ) );
+ btnRemoveProtocol->setPixmap( krLoader->loadIcon( "1rightarrow", TDEIcon::Small ) );
TQWhatsThis::add( btnRemoveProtocol, i18n( "Remove protocol from the link list." ) );
addSpacer( vbox1 );
@@ -94,10 +94,10 @@ KgProtocols::KgProtocols( bool first, TQWidget* parent, const char* name ) :
addSpacer( vbox2 );
btnAddMime = new TQPushButton( vbox2, "btnAddMimeButton" );
- btnAddMime->setPixmap( krLoader->loadIcon( "1leftarrow", KIcon::Small ) );
+ btnAddMime->setPixmap( krLoader->loadIcon( "1leftarrow", TDEIcon::Small ) );
TQWhatsThis::add( btnAddMime, i18n( "Add mime to the selected protocol on the link list." ) );
btnRemoveMime = new TQPushButton( vbox2, "btnRemoveMimeButton" );
- btnRemoveMime->setPixmap( krLoader->loadIcon( "1rightarrow", KIcon::Small ) );
+ btnRemoveMime->setPixmap( krLoader->loadIcon( "1rightarrow", TDEIcon::Small ) );
TQWhatsThis::add( btnRemoveMime, i18n( "Remove mime from the link list." ) );
addSpacer( vbox2 );
@@ -209,7 +209,7 @@ void KgProtocols::addProtocol( TQString name, bool changeCurrent )
{
protocolList->removeItem( protocolList->index( item ) );
TQListViewItem *listViewItem = new TQListViewItem( linkList, name );
- listViewItem->setPixmap( 0, krLoader->loadIcon( "exec", KIcon::Small ) );
+ listViewItem->setPixmap( 0, krLoader->loadIcon( "exec", TDEIcon::Small ) );
if( changeCurrent )
linkList->setCurrentItem( listViewItem );
@@ -265,7 +265,7 @@ void KgProtocols::addMime( TQString name, TQString protocol )
{
mimeList->removeItem( mimeList->index( item ) );
TQListViewItem *listViewItem = new TQListViewItem( currentListItem, name );
- listViewItem->setPixmap( 0, krLoader->loadIcon( "mime", KIcon::Small ) );
+ listViewItem->setPixmap( 0, krLoader->loadIcon( "mime", TDEIcon::Small ) );
currentListItem->setOpen( true );
}
}
diff --git a/krusader/Konfigurator/konfigurator.cpp b/krusader/Konfigurator/konfigurator.cpp
index ced3d4b..55815fa 100644
--- a/krusader/Konfigurator/konfigurator.cpp
+++ b/krusader/Konfigurator/konfigurator.cpp
@@ -89,32 +89,32 @@ void Konfigurator::createLayout( int startPage )
// startup
newContent(new KgStartup(firstTime, widget->addPage(i18n("Startup"),
i18n("Krusader's settings upon startup"),TQPixmap(krLoader->loadIcon("kfm_home",
- KIcon::Desktop,32)))));
+ TDEIcon::Desktop,32)))));
// look n' feel
newContent(new KgLookFeel(firstTime, widget->addPage(i18n("Look & Feel"),
- i18n("Look & Feel"),TQPixmap(krLoader->loadIcon("looknfeel",KIcon::Desktop,32)))));
+ i18n("Look & Feel"),TQPixmap(krLoader->loadIcon("looknfeel",TDEIcon::Desktop,32)))));
// colors
newContent(new KgColors(firstTime, widget->addPage(i18n("Colors"),
- i18n("Colors"),TQPixmap(krLoader->loadIcon("colors",KIcon::Desktop,32)))));
+ i18n("Colors"),TQPixmap(krLoader->loadIcon("colors",TDEIcon::Desktop,32)))));
// general
newContent(new KgGeneral(firstTime, widget->addPage(i18n("General"),
- i18n("Basic Operations"),TQPixmap(krLoader->loadIcon("configure",KIcon::Desktop,32)))));
+ i18n("Basic Operations"),TQPixmap(krLoader->loadIcon("configure",TDEIcon::Desktop,32)))));
// advanced
newContent(new KgAdvanced(firstTime, widget->addPage(i18n("Advanced"),
i18n("Be sure you know what you're doing!"),
- TQPixmap(krLoader->loadIcon("messagebox_warning",KIcon::Desktop,32)))));
+ TQPixmap(krLoader->loadIcon("messagebox_warning",TDEIcon::Desktop,32)))));
// archives
newContent(new KgArchives(firstTime, widget->addPage(i18n("Archives"),i18n("Customize the way Krusader deals with archives"),
- TQPixmap(krLoader->loadIcon("tgz",KIcon::Desktop,32)))));
+ TQPixmap(krLoader->loadIcon("tgz",TDEIcon::Desktop,32)))));
// dependencies
newContent(new KgDependencies(firstTime, widget->addPage(i18n("Dependencies"),i18n("Set the full path of the external applications"),
- TQPixmap(krLoader->loadIcon("kr_dependencies",KIcon::Desktop,32)))));
+ TQPixmap(krLoader->loadIcon("kr_dependencies",TDEIcon::Desktop,32)))));
// useractions
newContent(new KgUserActions(firstTime, widget->addPage(i18n("User Actions"),i18n("Configure your personal actions"),
- TQPixmap(krLoader->loadIcon("kr_useractions",KIcon::Desktop,32)))));
+ TQPixmap(krLoader->loadIcon("kr_useractions",TDEIcon::Desktop,32)))));
// protocols
newContent(new KgProtocols(firstTime, widget->addPage(i18n("Protocols"),
- i18n("Link mimes to protocols"), TQPixmap(krLoader->loadIcon("about_kde",KIcon::Desktop,32)))));
+ i18n("Link mimes to protocols"), TQPixmap(krLoader->loadIcon("about_kde",TDEIcon::Desktop,32)))));
widget->showPage( widget->pageIndex( kgFrames.at( startPage )->parentWidget() ) );
slotApplyEnable();
diff --git a/krusader/Konfigurator/krresulttabledialog.cpp b/krusader/Konfigurator/krresulttabledialog.cpp
index 335954e..9225875 100644
--- a/krusader/Konfigurator/krresulttabledialog.cpp
+++ b/krusader/Konfigurator/krresulttabledialog.cpp
@@ -46,7 +46,7 @@ KrResultTableDialog::KrResultTableDialog( TQWidget *parent, DialogType type,
// prepare the icon
_iconBox = new TQHBox(_page, "_iconBox");
_iconLabel = new TQLabel(_iconBox, "iconLabel");
- _iconLabel->setPixmap(krLoader->loadIcon(headerIcon, KIcon::Desktop, 32));
+ _iconLabel->setPixmap(krLoader->loadIcon(headerIcon, TDEIcon::Desktop, 32));
_iconLabel->setMinimumWidth(fontMetrics().maxWidth()*20);
_iconLabel->setAlignment( TQt::AlignLeft | TQt::AlignVCenter );
_iconLabel->setFixedSize( _iconLabel->sizeHint() );
diff --git a/krusader/Panel/krbriefview.cpp b/krusader/Panel/krbriefview.cpp
index 3b24c70..e2d3131 100644
--- a/krusader/Panel/krbriefview.cpp
+++ b/krusader/Panel/krbriefview.cpp
@@ -80,7 +80,7 @@ void KrBriefViewToolTip::maybeTip( const TQPoint &pos )
KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, TDEConfig *cfg, const char *name ):
- KIconView(parent, name), KrView( cfg ), header( headerIn ), _currDragItem( 0 ),
+ TDEIconView(parent, name), KrView( cfg ), header( headerIn ), _currDragItem( 0 ),
currentlyRenamedItem( 0 ), pressedItem( 0 ), mouseEvent( 0 ) {
setWidget( this );
_nameInTDEConfig = TQString( "KrBriefView" ) + TQString( ( left ? "Left" : "Right" ) );
@@ -175,7 +175,7 @@ void KrBriefView::resizeEvent ( TQResizeEvent * resEvent )
if( currentItem() )
visible = viewportRect.contains( currentItem()->rect() );
- KIconView::resizeEvent( resEvent );
+ TDEIconView::resizeEvent( resEvent );
redrawColumns();
if( visible && currentItem() )
@@ -300,7 +300,7 @@ void KrBriefView::addItems( vfs *v, bool addUpDir ) {
if ( !currentItem )
currentItem = firstItem();
- KIconView::setCurrentItem( currentItem );
+ TDEIconView::setCurrentItem( currentItem );
ensureItemVisible( currentItem );
op()->emitItemDescription( statusText );
@@ -322,7 +322,7 @@ TQString KrBriefView::getCurrentItem() const {
void KrBriefView::setCurrentItem( const TQString& name ) {
KrBriefViewItem * it = dynamic_cast<KrBriefViewItem*>(_dict[ name ]);
if ( it )
- KIconView::setCurrentItem( it );
+ TDEIconView::setCurrentItem( it );
}
void KrBriefView::clear() {
@@ -332,7 +332,7 @@ void KrBriefView::clear() {
}
op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
- KIconView::clear();
+ TDEIconView::clear();
KrView::clear();
}
@@ -405,7 +405,7 @@ void KrBriefView::handleQuickSearchEvent( TQKeyEvent * e ) {
case Key_Insert:
{
TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Space, 0, 0 );
- KIconView::keyPressEvent( & ev );
+ TDEIconView::keyPressEvent( & ev );
ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Down, 0, 0 );
keyPressEvent( & ev );
break;
@@ -594,7 +594,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
if( newCurrent ) // save the name of the file
name = static_cast<KrBriefViewItem*>( newCurrent ) ->name();
- KIconView::contentsMousePressEvent( e );
+ TDEIconView::contentsMousePressEvent( e );
if( name.isEmpty() || _dict.find( name ) == 0 ) // is the file still valid?
newCurrent = 0; // if not, don't do any crash...
@@ -634,7 +634,7 @@ void KrBriefView::contentsMouseReleaseEvent( TQMouseEvent * e ) {
e = transformMouseEvent( e );
- KIconView::contentsMouseReleaseEvent( e );
+ TDEIconView::contentsMouseReleaseEvent( e );
if( pressedItem ) {
TQPoint vp = contentsToViewport( e->pos() );
@@ -708,13 +708,13 @@ void KrBriefView::contentsMouseMoveEvent ( TQMouseEvent * e ) {
emit onViewport();
}
else
- KIconView::contentsMouseMoveEvent( e );
+ TDEIconView::contentsMouseMoveEvent( e );
}
void KrBriefView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
{
e = transformMouseEvent ( e );
- KIconView::contentsMouseDoubleClickEvent( e );
+ TDEIconView::contentsMouseDoubleClickEvent( e );
}
void KrBriefView::handleContextMenu( TQIconViewItem * it, const TQPoint & pos ) {
@@ -743,7 +743,7 @@ void KrBriefView::showContextMenu()
}
KrViewItem *KrBriefView::getKrViewItemAt( const TQPoint & vp ) {
- return dynamic_cast<KrViewItem*>( KIconView::findItem( vp ) );
+ return dynamic_cast<KrViewItem*>( TDEIconView::findItem( vp ) );
}
bool KrBriefView::acceptDrag( TQDropEvent* ) const {
@@ -754,7 +754,7 @@ void KrBriefView::contentsDropEvent( TQDropEvent * e ) {
_currDragItem = 0;
op()->emitGotDrop(e);
e->ignore();
- KIconView::contentsDropEvent( e );
+ TDEIconView::contentsDropEvent( e );
}
void KrBriefView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
@@ -764,7 +764,7 @@ void KrBriefView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
if( _currDragItem && !_currDragItem->VF->vfile_isDir() )
_currDragItem = 0;
- KIconView::contentsDragMoveEvent( e );
+ TDEIconView::contentsDragMoveEvent( e );
if( _currDragItem != oldDragItem )
{
@@ -780,7 +780,7 @@ void KrBriefView::contentsDragLeaveEvent ( TQDragLeaveEvent *e )
KrViewItem *oldDragItem = _currDragItem;
_currDragItem = 0;
- KIconView::contentsDragLeaveEvent( e );
+ TDEIconView::contentsDragLeaveEvent( e );
if( oldDragItem )
dynamic_cast<KrBriefViewItem *>( oldDragItem )->repaint();
@@ -794,7 +794,7 @@ void KrBriefView::imStartEvent(TQIMEvent* e)
}else {
TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
- KIconView::imStartEvent( e );
+ TDEIconView::imStartEvent( e );
else {
// first, show the quicksearch if its hidden
if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -850,7 +850,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
TQIconView::setCurrentItem( i );
TQIconView::ensureItemVisible( i );
}
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Down :
if ( e->state() == ControlButton || e->state() == ( ControlButton | ShiftButton ) ) { // let the panel handle it - jump to command line
@@ -862,7 +862,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
if ( e->state() == ShiftButton ) setSelected( i, !i->isSelected(), true );
i = i->nextItem();
if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Next: if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
TQIconViewItem * i = currentItem(), *j;
@@ -872,7 +872,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->nextItem() ); --page )
i = j;
if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Prior: if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
TQIconViewItem * i = currentItem(), *j;
@@ -882,13 +882,13 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->prevItem() ); --page )
i = j;
if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Home: if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
if ( e->state() & ShiftButton ) /* Shift+Home */
{
clearSelection();
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
op()->emitSelectionChanged();
arrangeItemsInGrid();
break;
@@ -896,13 +896,13 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
TQIconViewItem * i = firstItem();
if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
}
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_End: if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
if ( e->state() & ShiftButton ) /* Shift+End */
{
clearSelection();
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
op()->emitSelectionChanged();
arrangeItemsInGrid();
break;
@@ -915,7 +915,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
break;
}
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Enter :
case Key_Return : {
@@ -977,7 +977,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
TQIconView::setCurrentItem( newCurrent );
TQIconView::ensureItemVisible( newCurrent );
}
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Backspace : // Terminal Emulator bugfix
if ( e->state() == ControlButton || e->state() == ShiftButton ) { // let the panel handle it
@@ -1026,7 +1026,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
TQIconView::setCurrentItem( newCurrent );
TQIconView::ensureItemVisible( newCurrent );
}
- } else KIconView::keyPressEvent(e);
+ } else TDEIconView::keyPressEvent(e);
break;
case Key_Delete : // kill file
@@ -1079,7 +1079,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
}
case Key_A : // mark all
if ( e->state() == ControlButton ) {
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
updateView();
break;
}
@@ -1100,7 +1100,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
{
TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
else {
// first, show the quicksearch if its hidden
if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -1125,7 +1125,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
ACTIVE_PANEL->quickSearch->clear();
krDirUp->setEnabled( true );
}
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
}
}
// emit the new item description
@@ -1260,7 +1260,7 @@ bool KrBriefView::event( TQEvent *e ) {
op()->emitNeedFocus();
setFocus();
}
- return KIconView::event( e );
+ return TDEIconView::event( e );
}
@@ -1270,7 +1270,7 @@ bool KrBriefView::eventFilter( TQObject * watched, TQEvent * e )
{
if( e->type() == TQEvent::Hide || e->type() == TQEvent::Show )
{
- bool res = KIconView::eventFilter( watched, e );
+ bool res = TDEIconView::eventFilter( watched, e );
arrangeItemsInGrid();
return res;
}
@@ -1284,7 +1284,7 @@ bool KrBriefView::eventFilter( TQObject * watched, TQEvent * e )
}
return FALSE;
}
- return KIconView::eventFilter( watched, e );
+ return TDEIconView::eventFilter( watched, e );
}
void KrBriefView::makeItemVisible( const KrViewItem *item ) {
diff --git a/krusader/Panel/krbriefviewitem.cpp b/krusader/Panel/krbriefviewitem.cpp
index de38e27..7981f11 100644
--- a/krusader/Panel/krbriefviewitem.cpp
+++ b/krusader/Panel/krbriefviewitem.cpp
@@ -18,7 +18,7 @@ int KrBriefViewItem::expHeight = 0;
#endif // FASTER
KrBriefViewItem::KrBriefViewItem(KrBriefView *parent, TQIconViewItem *after, vfile *vf):
- KIconViewItem(parent, after), KrViewItem(vf, parent->properties()) {
+ TDEIconViewItem(parent, after), KrViewItem(vf, parent->properties()) {
#ifdef FASTER
initiated = false;
// get the expected height of an item - should be done only once
@@ -199,7 +199,7 @@ void KrBriefViewItem::repaintItem()
// for keeping the exact item heights...
void KrBriefViewItem::calcRect ( const TQString & text_ )
{
- KIconViewItem::calcRect( text_ );
+ TDEIconViewItem::calcRect( text_ );
TQRect rec = rect();
int gridX = iconView()->gridX();
diff --git a/krusader/Panel/krbriefviewitem.h b/krusader/Panel/krbriefviewitem.h
index fd2f03a..c663bd1 100644
--- a/krusader/Panel/krbriefviewitem.h
+++ b/krusader/Panel/krbriefviewitem.h
@@ -42,13 +42,13 @@
class TQPixmap;
class KrBriefView;
-class KrBriefViewItem : public KIconViewItem, public KrViewItem {
+class KrBriefViewItem : public TDEIconViewItem, public KrViewItem {
friend class KrBriefView;
friend class KrCalcSpaceDialog;
public:
KrBriefViewItem(KrBriefView *parent, TQIconViewItem *after, vfile *vf);
- inline bool isSelected() const { return KIconViewItem::isSelected(); }
- inline void setSelected(bool s) { KIconViewItem::setSelected(s); }
+ inline bool isSelected() const { return TDEIconViewItem::isSelected(); }
+ inline void setSelected(bool s) { TDEIconViewItem::setSelected(s); }
inline void cancelRename() { removeRenameBox(); }
int compare(TQIconViewItem *i) const;
virtual void repaintItem();
diff --git a/krusader/Panel/krpopupmenu.cpp b/krusader/Panel/krpopupmenu.cpp
index d6ab5c0..6e4a1af 100644
--- a/krusader/Panel/krpopupmenu.cpp
+++ b/krusader/Panel/krpopupmenu.cpp
@@ -62,7 +62,7 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, TQWidget *parent) : TDEPopupMenu(p
// open in a new tab (if folder)
if ( vf->vfile_isDir() ) {
insertItem( i18n( "Open in New Tab" ), OPEN_TAB_ID );
- changeItem( OPEN_TAB_ID, krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in New Tab" ) );
+ changeItem( OPEN_TAB_ID, krLoader->loadIcon( "tab_new", TDEIcon::Panel ), i18n( "Open in New Tab" ) );
}
insertSeparator();
}
@@ -93,12 +93,12 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, TQWidget *parent) : TDEPopupMenu(p
KService::Ptr service = offers[ i ].service();
if ( service->isValid() && service->type() == "Application" ) {
openWith.insertItem( service->name(), SERVICE_LIST_ID + i );
- openWith.changeItem( SERVICE_LIST_ID + i, service->pixmap( KIcon::Small ), service->name() );
+ openWith.changeItem( SERVICE_LIST_ID + i, service->pixmap( TDEIcon::Small ), service->name() );
}
}
openWith.insertSeparator();
if ( vf->vfile_isDir() )
- openWith.insertItem( krLoader->loadIcon( "konsole", KIcon::Small ), i18n( "Terminal" ), OPEN_TERM_ID );
+ openWith.insertItem( krLoader->loadIcon( "konsole", TDEIcon::Small ), i18n( "Terminal" ), OPEN_TERM_ID );
openWith.insertItem( i18n( "Other..." ), CHOOSE_ID );
insertItem( TQPixmap(), &openWith, OPEN_WITH_ID );
changeItem( OPEN_WITH_ID, i18n( "Open With" ) );
@@ -212,8 +212,8 @@ void KrPopupMenu::addEmptyMenuEntries() {
}
void KrPopupMenu::addCreateNewMenu() {
- createNewPopup.insertItem( krLoader->loadIcon( "folder", KIcon::Small ), i18n("Folder..."), MKDIR_ID);
- createNewPopup.insertItem( krLoader->loadIcon( "txt", KIcon::Small ), i18n("Text File..."), NEW_TEXT_FILE_ID);
+ createNewPopup.insertItem( krLoader->loadIcon( "folder", TDEIcon::Small ), i18n("Folder..."), MKDIR_ID);
+ createNewPopup.insertItem( krLoader->loadIcon( "txt", TDEIcon::Small ), i18n("Text File..."), NEW_TEXT_FILE_ID);
insertItem( TQPixmap(), &createNewPopup, CREATE_NEW_ID);
changeItem( CREATE_NEW_ID, i18n( "Create New" ) );
diff --git a/krusader/Panel/listpanel.cpp b/krusader/Panel/listpanel.cpp
index 9444d82..9d54bea 100644
--- a/krusader/Panel/listpanel.cpp
+++ b/krusader/Panel/listpanel.cpp
@@ -168,13 +168,13 @@ ListPanel::ListPanel( TQString typeIn, TQWidget *parent, bool &left, const char
// a cancel button for the inplace refresh mechanism
inlineRefreshCancelButton = new KPushButton(this);
inlineRefreshCancelButton->setFixedSize( 22, 20 );
- inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", KIcon::Toolbar, 16));
+ inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", TDEIcon::Toolbar, 16));
connect(inlineRefreshCancelButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(inlineRefreshCancel()));
// a quick button to open the popup panel
popupBtn = new TQToolButton( this, "popupbtn" );
popupBtn->setFixedSize( 22, 20 );
- popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
+ popupBtn->setPixmap(krLoader->loadIcon("1uparrow", TDEIcon::Toolbar, 16));
connect(popupBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(togglePanelPopup()));
TQToolTip::add( popupBtn, i18n( "Open the popup panel" ) );
totalsLayout->addWidget(totals);
@@ -194,7 +194,7 @@ ListPanel::ListPanel( TQString typeIn, TQWidget *parent, bool &left, const char
bool clearButton = krConfig->readBoolEntry("Clear Location Bar Visible", _ClearLocation);
if (clearButton){
clearOrigin = new TQToolButton(hbox, "clearorigin");
- clearOrigin->setPixmap(krLoader->loadIcon("locationbar_erase", KIcon::Toolbar, 16));
+ clearOrigin->setPixmap(krLoader->loadIcon("locationbar_erase", TDEIcon::Toolbar, 16));
TQToolTip::add( clearOrigin, i18n( "Clear the location bar" ) );
}
@@ -413,13 +413,13 @@ void ListPanel::togglePanelPopup() {
}
popup->show();
- popupBtn->setPixmap(krLoader->loadIcon("1downarrow", KIcon::Toolbar, 16));
+ popupBtn->setPixmap(krLoader->loadIcon("1downarrow", TDEIcon::Toolbar, 16));
TQToolTip::add( popupBtn, i18n( "Close the popup panel" ) );
} else {
popupSizes.clear();
popupSizes = dynamic_cast<TQSplitter*>(popup->parent())->sizes();
popup->hide();
- popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
+ popupBtn->setPixmap(krLoader->loadIcon("1uparrow", TDEIcon::Toolbar, 16));
TQToolTip::add( popupBtn, i18n( "Open the popup panel" ) );
TQValueList<int> lst;
diff --git a/krusader/Panel/panelpopup.cpp b/krusader/Panel/panelpopup.cpp
index a43bd50..0c10850 100644
--- a/krusader/Panel/panelpopup.cpp
+++ b/krusader/Panel/panelpopup.cpp
@@ -64,7 +64,7 @@ PanelPopup::PanelPopup( TQSplitter *parent, bool left ) : TQWidget( parent ),
treeBtn = new TQToolButton(this);
TQToolTip::add(treeBtn, i18n("Tree Panel: a tree view of the local file system"));
- treeBtn->setPixmap(krLoader->loadIcon( "view_tree", KIcon::Toolbar, 16 ));
+ treeBtn->setPixmap(krLoader->loadIcon( "view_tree", TDEIcon::Toolbar, 16 ));
treeBtn->setFixedSize(20, 20);
treeBtn->setToggleButton(true);
btns->insert(treeBtn, Tree);
@@ -72,28 +72,28 @@ PanelPopup::PanelPopup( TQSplitter *parent, bool left ) : TQWidget( parent ),
previewBtn = new TQToolButton(this);
TQToolTip::add(previewBtn, i18n("Preview Panel: display a preview of the current file"));
- previewBtn->setPixmap(krLoader->loadIcon( "thumbnail", KIcon::Toolbar, 16 ));
+ previewBtn->setPixmap(krLoader->loadIcon( "thumbnail", TDEIcon::Toolbar, 16 ));
previewBtn->setFixedSize(20, 20);
previewBtn->setToggleButton(true);
btns->insert(previewBtn, Preview);
quickBtn = new TQToolButton(this);
TQToolTip::add(quickBtn, i18n("Quick Panel: quick way to perform actions"));
- quickBtn->setPixmap(krLoader->loadIcon( "misc", KIcon::Toolbar, 16 ));
+ quickBtn->setPixmap(krLoader->loadIcon( "misc", TDEIcon::Toolbar, 16 ));
quickBtn->setFixedSize(20, 20);
quickBtn->setToggleButton(true);
btns->insert(quickBtn, QuickPanel);
viewerBtn = new TQToolButton(this);
TQToolTip::add(viewerBtn, i18n("View Panel: view the current file"));
- viewerBtn->setPixmap(krLoader->loadIcon( "viewmag", KIcon::Toolbar, 16 ));
+ viewerBtn->setPixmap(krLoader->loadIcon( "viewmag", TDEIcon::Toolbar, 16 ));
viewerBtn->setFixedSize(20, 20);
viewerBtn->setToggleButton(true);
btns->insert(viewerBtn, View);
duBtn = new TQToolButton(this);
TQToolTip::add(duBtn, i18n("Disk Usage Panel: view the usage of a directory"));
- duBtn->setPixmap(krLoader->loadIcon( "kr_diskusage", KIcon::Toolbar, 16 ));
+ duBtn->setPixmap(krLoader->loadIcon( "kr_diskusage", TDEIcon::Toolbar, 16 ));
duBtn->setFixedSize(20, 20);
duBtn->setToggleButton(true);
btns->insert(duBtn, DskUsage);
@@ -168,19 +168,19 @@ PanelPopup::PanelPopup( TQSplitter *parent, bool left ) : TQWidget( parent ),
this, TQT_SLOT(quickSelect(const TQString& )));
TQToolButton *qselectBtn = new TQToolButton(quickPanel);
- qselectBtn->setPixmap(krLoader->loadIcon( "kr_selectall", KIcon::Toolbar, 16 ));
+ qselectBtn->setPixmap(krLoader->loadIcon( "kr_selectall", TDEIcon::Toolbar, 16 ));
qselectBtn->setFixedSize(20, 20);
TQToolTip::add( qselectBtn, i18n("apply the selection") );
connect(qselectBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(quickSelect()));
TQToolButton *qstoreBtn = new TQToolButton(quickPanel);
- qstoreBtn->setPixmap(krLoader->loadIcon( "filesave", KIcon::Toolbar, 16 ));
+ qstoreBtn->setPixmap(krLoader->loadIcon( "filesave", TDEIcon::Toolbar, 16 ));
qstoreBtn->setFixedSize(20, 20);
TQToolTip::add( qstoreBtn, i18n("store the current selection") );
connect(qstoreBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(quickSelectStore()));
TQToolButton *qsettingsBtn = new TQToolButton(quickPanel);
- qsettingsBtn->setPixmap(krLoader->loadIcon( "configure", KIcon::Toolbar, 16 ));
+ qsettingsBtn->setPixmap(krLoader->loadIcon( "configure", TDEIcon::Toolbar, 16 ));
qsettingsBtn->setFixedSize(20, 20);
TQToolTip::add( qsettingsBtn, i18n("select group dialog") );
connect(qsettingsBtn, TQT_SIGNAL(clicked()), krSelect, TQT_SLOT(activate()));
diff --git a/krusader/kicons.cpp b/krusader/kicons.cpp
index 9f1f3a7..fbf40ed 100644
--- a/krusader/kicons.cpp
+++ b/krusader/kicons.cpp
@@ -37,9 +37,9 @@ TQPixmap FL_LOADICON(TQString name) {
krConfig->setGroup("Look&Feel");
int size = (krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
if (size!=22)
- return krLoader->loadIcon(name,KIcon::Desktop,size);
+ return krLoader->loadIcon(name,TDEIcon::Desktop,size);
// else implied
- return TQIconSet(krLoader->loadIcon(name,KIcon::Desktop,32)).pixmap(TQIconSet::Small,true);
+ return TQIconSet(krLoader->loadIcon(name,TDEIcon::Desktop,32)).pixmap(TQIconSet::Small,true);
}
const char * no_xpm[] = {
diff --git a/krusader/kicons.h b/krusader/kicons.h
index bdc0c4b..fd5eb7b 100644
--- a/krusader/kicons.h
+++ b/krusader/kicons.h
@@ -7,11 +7,11 @@
#include <kicontheme.h>
// can be used everywhere - EXCEPT in KFileList related calls, loads the icon according to
-// KIcon::Desktop settings and resizes it to a smaller size. If this is used to toolbuttons,
+// TDEIcon::Desktop settings and resizes it to a smaller size. If this is used to toolbuttons,
// the the icon is resized again to fit into the toolbutton or menu.
// IMPORTANT: this SHOULD NOT BE USED for actions. If creating an action, just state the file-name
// of the icon to allow automatic resizing when needed.
-#define LOADICON(X) TQIconSet(krLoader->loadIcon(X,KIcon::Desktop)).pixmap(TQIconSet::Small,true)
+#define LOADICON(X) TQIconSet(krLoader->loadIcon(X,TDEIcon::Desktop)).pixmap(TQIconSet::Small,true)
// used only for calls within the tdefilelist framework, handles icon sizes
TQPixmap FL_LOADICON(TQString name);
diff --git a/krusader/krusader.cpp b/krusader/krusader.cpp
index a21b372..43698b0 100644
--- a/krusader/krusader.cpp
+++ b/krusader/krusader.cpp
@@ -367,7 +367,7 @@ Krusader::Krusader() : KParts::MainWindow(0,0,WType_TopLevel|WDestructiveClose|T
// This enables Krusader to show a tray icon
sysTray = new KSystemTray( this );
// Krusader::privIcon() returns either "krusader_blue" or "krusader_red" if the user got root-privileges
- sysTray->setPixmap( iconLoader->loadIcon( privIcon(), KIcon::Panel, 22 ) );
+ sysTray->setPixmap( iconLoader->loadIcon( privIcon(), TDEIcon::Panel, 22 ) );
sysTray->hide();
connect( sysTray, TQT_SIGNAL( quitSelected() ), TQT_TQOBJECT(this), TQT_SLOT( setDirectExit() ) );
diff --git a/krusader/krusader.h b/krusader/krusader.h
index 4f5fa9a..b8df417 100644
--- a/krusader/krusader.h
+++ b/krusader/krusader.h
@@ -58,7 +58,7 @@ class KRPleaseWaitHandler;
class KrusaderView;
class TDEProcess;
class KRslots;
-class KIconLoader;
+class TDEIconLoader;
class KSystemTray;
class UserMenu;
class UserAction;
@@ -119,7 +119,7 @@ class Krusader : public KParts::MainWindow, public DCOPObject {
KMountMan *mountMan; // krusader's Mount Manager
KrusaderView *mainView; // The GUI
TDEConfig *config; // allow everyone to access the config
- KIconLoader *iconLoader; // the app's icon loader
+ TDEIconLoader *iconLoader; // the app's icon loader
PopularUrls *popularUrls; // holds a sorted list of the most popular urls visited
QueueManager *queueManager;
// Actions
diff --git a/krusader/Panel/krbriefview.h b/krusader/Panel/krbriefview.h
index 8d7f6b6..5cb61f1 100644
--- a/krusader/Panel/krbriefview.h
+++ b/krusader/Panel/krbriefview.h
@@ -48,12 +48,12 @@ class TQHeader;
/**
* KrBriefView implements everthing and anything regarding a brief view in a filemananger.
* IT MUST USE KrViewItem as the children to it's *KIconView. KrBriefView and KrViewItem are
* tightly coupled and the view will not work with other kinds of items.
* Apart from this, the view is self-reliant and you can use the vast interface to get whatever
* information is necessery from it.
*/
-class KrBriefView: public KIconView, public KrView {
+class KrBriefView: public TDEIconView, public KrView {
friend class KrBriefViewItem;
Q_OBJECT
@@ -75,8 +75,8 @@ public:
virtual void updateView();
virtual void updateItem(KrViewItem* item );
virtual void clear();
- virtual void sort() { if( sortDirection() ) sortOrderChanged();KIconView::sort( true ); }
- virtual void sort( bool ascending ) { if( sortDirection() != ascending ) sortOrderChanged();KIconView::sort( ascending ); }
+ virtual void sort() { if( sortDirection() ) sortOrderChanged();TDEIconView::sort( true ); }
+ virtual void sort( bool ascending ) { if( sortDirection() != ascending ) sortOrderChanged();TDEIconView::sort( ascending ); }
virtual void prepareForActive();
virtual void prepareForPassive();
virtual void saveSettings() {}
@@ -48,12 +48,12 @@ class TQHeader;
/**
* KrBriefView implements everthing and anything regarding a brief view in a filemananger.
- * IT MUST USE KrViewItem as the children to it's *KIconView. KrBriefView and KrViewItem are
+ * IT MUST USE KrViewItem as the children to it's *TDEIconView. KrBriefView and KrViewItem are
* tightly coupled and the view will not work with other kinds of items.
* Apart from this, the view is self-reliant and you can use the vast interface to get whatever